==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/WebRatingDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var WebRatingDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebRatingDescription, _super);
    function WebRatingDescription() {
        var _this = _super.call(this) || this;
        _this.l = 0;
        _this.m = 0;
        _this.w = null;
        _this.u = null;
        _this.t = null;
        _this.x = null;
        _this.n = 0;
        _this.f = false;
        _this.g = false;
        _this.h = false;
        _this.v = null;
        _this.r = null;
        _this.s = null;
        return _this;
    }
    WebRatingDescription.prototype.get_type = function () {
        return "WebRating";
    };
    Object.defineProperty(WebRatingDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebRatingDescription.prototype, "max", {
        get: function () {
            return this.l;
        },
        set: function (a) {
            this.l = a;
            this.e("Max");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebRatingDescription.prototype, "step", {
        get: function () {
            return this.m;
        },
        set: function (a) {
            this.m = a;
            this.e("Step");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebRatingDescription.prototype, "symbol", {
        get: function () {
            return this.w;
        },
        set: function (a) {
            this.w = a;
            this.e("Symbol");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebRatingDescription.prototype, "name", {
        get: function () {
            return this.u;
        },
        set: function (a) {
            this.u = a;
            this.e("Name");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebRatingDescription.prototype, "label", {
        get: function () {
            return this.t;
        },
        set: function (a) {
            this.t = a;
            this.e("Label");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebRatingDescription.prototype, "valueFormat", {
        get: function () {
            return this.x;
        },
        set: function (a) {
            this.x = a;
            this.e("ValueFormat");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebRatingDescription.prototype, "value", {
        get: function () {
            return this.n;
        },
        set: function (a) {
            this.n = a;
            this.e("Value");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebRatingDescription.prototype, "disabled", {
        get: function () {
            return this.f;
        },
        set: function (a) {
            this.f = a;
            this.e("Disabled");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebRatingDescription.prototype, "hoverPreview", {
        get: function () {
            return this.g;
        },
        set: function (a) {
            this.g = a;
            this.e("HoverPreview");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebRatingDescription.prototype, "readonly", {
        get: function () {
            return this.h;
        },
        set: function (a) {
            this.h = a;
            this.e("Readonly");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebRatingDescription.prototype, "size", {
        get: function () {
            return this.v;
        },
        set: function (a) {
            this.v = a;
            this.e("Size");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebRatingDescription.prototype, "changeRef", {
        get: function () {
            return this.r;
        },
        set: function (a) {
            this.r = a;
            this.e("ChangeRef");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebRatingDescription.prototype, "hoverRef", {
        get: function () {
            return this.s;
        },
        set: function (a) {
            this.s = a;
            this.e("HoverRef");
        },
        enumerable: false,
        configurable: true
    });
    WebRatingDescription.$t = markType(WebRatingDescription, 'WebRatingDescription', Description.$);
    return WebRatingDescription;
}(Description));
export { WebRatingDescription };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebRatingDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var WebRatingDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebRatingDescription, _super);
    function WebRatingDescription() {
        var _this = _super.call(this) || this;
        _this.n = 0;
        _this.o = 0;
        _this.w = null;
        _this.v = null;
        _this.y = null;
        _this.p = 0;
        _this.f = false;
        _this.g = false;
        _this.h = false;
        _this.i = false;
        _this.x = null;
        _this.t = null;
        _this.u = null;
        return _this;
    }
    WebRatingDescription.prototype.get_type = function () {
        return "WebRating";
    };
    Object.defineProperty(WebRatingDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebRatingDescription.prototype, "max", {
        get: function () {
            return this.n;
        },
        set: function (a) {
            this.n = a;
            this.e("Max");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebRatingDescription.prototype, "step", {
        get: function () {
            return this.o;
        },
        set: function (a) {
            this.o = a;
            this.e("Step");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebRatingDescription.prototype, "name", {
        get: function () {
            return this.w;
        },
        set: function (a) {
            this.w = a;
            this.e("Name");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebRatingDescription.prototype, "label", {
        get: function () {
            return this.v;
        },
        set: function (a) {
            this.v = a;
            this.e("Label");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebRatingDescription.prototype, "valueFormat", {
        get: function () {
            return this.y;
        },
        set: function (a) {
            this.y = a;
            this.e("ValueFormat");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebRatingDescription.prototype, "value", {
        get: function () {
            return this.p;
        },
        set: function (a) {
            this.p = a;
            this.e("Value");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebRatingDescription.prototype, "disabled", {
        get: function () {
            return this.f;
        },
        set: function (a) {
            this.f = a;
            this.e("Disabled");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebRatingDescription.prototype, "hoverPreview", {
        get: function () {
            return this.g;
        },
        set: function (a) {
            this.g = a;
            this.e("HoverPreview");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebRatingDescription.prototype, "readonly", {
        get: function () {
            return this.h;
        },
        set: function (a) {
            this.h = a;
            this.e("Readonly");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebRatingDescription.prototype, "single", {
        get: function () {
            return this.i;
        },
        set: function (a) {
            this.i = a;
            this.e("Single");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebRatingDescription.prototype, "size", {
        get: function () {
            return this.x;
        },
        set: function (a) {
            this.x = a;
            this.e("Size");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebRatingDescription.prototype, "changeRef", {
        get: function () {
            return this.t;
        },
        set: function (a) {
            this.t = a;
            this.e("ChangeRef");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebRatingDescription.prototype, "hoverRef", {
        get: function () {
            return this.u;
        },
        set: function (a) {
            this.u = a;
            this.e("HoverRef");
        },
        enumerable: false,
        configurable: true
    });
    WebRatingDescription.$t = markType(WebRatingDescription, 'WebRatingDescription', Description.$);
    return WebRatingDescription;
}(Description));
export { WebRatingDescription };
